## ----setup, echo=FALSE, results="hide"----------------------------------------
knitr::opts_chunk$set(tidy=FALSE, cache=TRUE,
dev="png",
message=TRUE, error=FALSE, warning=TRUE)

## ----vignettes, eval=FALSE----------------------------------------------------
#  browseVignettes("distinct")

## ----citation, eval=FALSE-----------------------------------------------------
#  citation("distinct")

## ----Bioconductor_installation, eval=FALSE------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#    install.packages("BiocManager")
#  BiocManager::install("distinct")

## ----github_installation, eval=FALSE------------------------------------------
#  devtools::install_github("SimoneTiberi/distinct")

## ----github_installation_2, eval=FALSE----------------------------------------
#  devtools::install_github("SimoneTiberi/distinct",
#                           build_opts = c("--no-resave-data", "--no-manual"))

## ----load-example-data, message = FALSE---------------------------------------
library(SingleCellExperiment)
data("Kang_subset", package = "distinct")
Kang_subset

## ----visualize colData--------------------------------------------------------
colData(Kang_subset)

## ----visualize experimental design--------------------------------------------
Kang_subset@metadata$experiment_info

## ----load_distinct, message=FALSE---------------------------------------------
library(distinct)

## ----create_design------------------------------------------------------------
samples = Kang_subset@metadata$experiment_info$sample_id
group = Kang_subset@metadata$experiment_info$stim
design = model.matrix(~group)
# rownames of the design must indicate sample ids:
rownames(design) = samples
design

## ----differential-analyses----------------------------------------------------
set.seed(61217)

res = distinct_test(
  x = Kang_subset, 
  name_assays_expression = "logcounts",
  name_cluster = "cell",
  name_sample = "sample_id",
  design = design,
  column_to_test = 2,
  min_non_zero_cells = 20,
  n_cores = 2)

## ----visualize-results--------------------------------------------------------
head(top_results(res))

## ----visualize-results-one-cluster--------------------------------------------
top_results(res, cluster = "Dendritic cells")

## ----define-batches-----------------------------------------------------------
batch = factor(c("A", "B", "C", "A", "B", "C"))

design = model.matrix(~group + batch)
# rownames of the design must indicate sample ids:
rownames(design) = samples
design

## ----differential-analyses-with-batches---------------------------------------
set.seed(61217)

res_batches = distinct_test(
  x = Kang_subset, 
  name_assays_expression = "logcounts",
  name_cluster = "cell",
  name_sample = "sample_id",
  design = design,
  column_to_test = 2,
  min_non_zero_cells = 20,
  n_cores = 2)

head(top_results(res_batches))

top_results(res, cluster = "Dendritic cells")

## ----UpsetR plot--------------------------------------------------------------
library(UpSetR)
res_by_cluster = split( ifelse(res$p_adj.glb < 0.01, 1, 0), res$cluster_id)
upset(data.frame(do.call(cbind, res_by_cluster)), nsets = 10, nintersects = 20)

## ----plotExpression-----------------------------------------------------------
# select cluster of cells:
cluster = "Dendritic cells"
sel_cluster = res$cluster_id == cluster
sel_column = Kang_subset$cell == cluster

# select significant genes:
sel_genes = res$p_adj.glb < 0.01
genes = as.character(res$gene[sel_cluster & sel_genes])

# make violin plots:
library(scater)
plotExpression(Kang_subset[,sel_column],
                     features = genes, exprs_values = "logcounts",
                     log2_values = FALSE,
                     x = "sample_id", colour_by = "stim", ncol = 3) +
        guides(fill = guide_legend(override.aes = list(size = 5, alpha = 1))) +
        theme(axis.text.x = element_text(angle = 45, hjust = 1))

## ----plot_densitied-----------------------------------------------------------
plot_densities(x = Kang_subset,
            gene = genes[1],
            cluster = "Dendritic cells",
            name_assays_expression = "logcounts",
            name_cluster = "cell",
            name_sample = "sample_id",
            name_group = "stim")

## ----plot_cdfs----------------------------------------------------------------
plot_cdfs(x = Kang_subset,
                 gene = genes[1],
                 cluster = "Dendritic cells",
                 name_assays_expression = "logcounts",
                 name_cluster = "cell",
                 name_sample = "sample_id",
                 name_group = "stim")

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

